==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/MABContainerHealthDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.MABContainerHealthDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * MAB workload-specific Health Details.
 * @property code Health Code
 * @property message Health Message
 * @property recommendations Health Recommended Actions
 * @property title Health Title
 */
public data class MABContainerHealthDetailsArgs(
    public val code: Output<Int>? = null,
    public val message: Output<String>? = null,
    public val recommendations: Output<List<String>>? = null,
    public val title: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.MABContainerHealthDetailsArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.MABContainerHealthDetailsArgs =
        com.pulumi.azurenative.recoveryservices.inputs.MABContainerHealthDetailsArgs.builder()
            .code(code?.applyValue({ args0 -> args0 }))
            .message(message?.applyValue({ args0 -> args0 }))
            .recommendations(recommendations?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .title(title?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MABContainerHealthDetailsArgs].
 */
@PulumiTagMarker
public class MABContainerHealthDetailsArgsBuilder internal constructor() {
    private var code: Output<Int>? = null

    private var message: Output<String>? = null

    private var recommendations: Output<List<String>>? = null

    private var title: Output<String>? = null

    /**
     * @param value Health Code
     */
    @JvmName("hopkncjkugsyjqxj")
    public suspend fun code(`value`: Output<Int>) {
        this.code = value
    }

    /**
     * @param value Health Message
     */
    @JvmName("xwsxqvjyeetxcsoq")
    public suspend fun message(`value`: Output<String>) {
        this.message = value
    }

    /**
     * @param value Health Recommended Actions
     */
    @JvmName("cvxvuxqrdoyrckci")
    public suspend fun recommendations(`value`: Output<List<String>>) {
        this.recommendations = value
    }

    @JvmName("ugjryaggnclhrmtg")
    public suspend fun recommendations(vararg values: Output<String>) {
        this.recommendations = Output.all(values.asList())
    }

    /**
     * @param values Health Recommended Actions
     */
    @JvmName("pkyyyjbdtrftcsto")
    public suspend fun recommendations(values: List<Output<String>>) {
        this.recommendations = Output.all(values)
    }

    /**
     * @param value Health Title
     */
    @JvmName("oocojglayflookaj")
    public suspend fun title(`value`: Output<String>) {
        this.title = value
    }

    /**
     * @param value Health Code
     */
    @JvmName("dqieyjefubtculew")
    public suspend fun code(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.code = mapped
    }

    /**
     * @param value Health Message
     */
    @JvmName("xyuxbfevmviqpgnk")
    public suspend fun message(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.message = mapped
    }

    /**
     * @param value Health Recommended Actions
     */
    @JvmName("tmtefvrmoqxcmypf")
    public suspend fun recommendations(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.recommendations = mapped
    }

    /**
     * @param values Health Recommended Actions
     */
    @JvmName("atnoeutfiwntbehn")
    public suspend fun recommendations(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.recommendations = mapped
    }

    /**
     * @param value Health Title
     */
    @JvmName("uarnvsruntfciuum")
    public suspend fun title(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.title = mapped
    }

    internal fun build(): MABContainerHealthDetailsArgs = MABContainerHealthDetailsArgs(
        code = code,
        message = message,
        recommendations = recommendations,
        title = title,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/MABContainerHealthDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.MABContainerHealthDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * MAB workload-specific Health Details.
 * @property code Health Code
 * @property message Health Message
 * @property recommendations Health Recommended Actions
 * @property title Health Title
 */
public data class MABContainerHealthDetailsArgs(
    public val code: Output<Int>? = null,
    public val message: Output<String>? = null,
    public val recommendations: Output<List<String>>? = null,
    public val title: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.MABContainerHealthDetailsArgs> {
    override fun toJava():
        com.pulumi.azurenative.recoveryservices.inputs.MABContainerHealthDetailsArgs =
        com.pulumi.azurenative.recoveryservices.inputs.MABContainerHealthDetailsArgs.builder()
            .code(code?.applyValue({ args0 -> args0 }))
            .message(message?.applyValue({ args0 -> args0 }))
            .recommendations(recommendations?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .title(title?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MABContainerHealthDetailsArgs].
 */
@PulumiTagMarker
public class MABContainerHealthDetailsArgsBuilder internal constructor() {
    private var code: Output<Int>? = null

    private var message: Output<String>? = null

    private var recommendations: Output<List<String>>? = null

    private var title: Output<String>? = null

    /**
     * @param value Health Code
     */
    @JvmName("oryolcxfyiqewtqs")
    public suspend fun code(`value`: Output<Int>) {
        this.code = value
    }

    /**
     * @param value Health Message
     */
    @JvmName("nucrgdhgqjfemplm")
    public suspend fun message(`value`: Output<String>) {
        this.message = value
    }

    /**
     * @param value Health Recommended Actions
     */
    @JvmName("gerdxygmbjcnmfso")
    public suspend fun recommendations(`value`: Output<List<String>>) {
        this.recommendations = value
    }

    @JvmName("qyecssiyrokixaaf")
    public suspend fun recommendations(vararg values: Output<String>) {
        this.recommendations = Output.all(values.asList())
    }

    /**
     * @param values Health Recommended Actions
     */
    @JvmName("twntaoabuwiqdssh")
    public suspend fun recommendations(values: List<Output<String>>) {
        this.recommendations = Output.all(values)
    }

    /**
     * @param value Health Title
     */
    @JvmName("tmoprkxrljkxoorq")
    public suspend fun title(`value`: Output<String>) {
        this.title = value
    }

    /**
     * @param value Health Code
     */
    @JvmName("ujliqllujovortuc")
    public suspend fun code(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.code = mapped
    }

    /**
     * @param value Health Message
     */
    @JvmName("huawomubgpsotjju")
    public suspend fun message(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.message = mapped
    }

    /**
     * @param value Health Recommended Actions
     */
    @JvmName("nlvmfjktvwfnfrxn")
    public suspend fun recommendations(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.recommendations = mapped
    }

    /**
     * @param values Health Recommended Actions
     */
    @JvmName("uvvxhpgbwcxhnepa")
    public suspend fun recommendations(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.recommendations = mapped
    }

    /**
     * @param value Health Title
     */
    @JvmName("hxmijdiykiuylexq")
    public suspend fun title(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.title = mapped
    }

    internal fun build(): MABContainerHealthDetailsArgs = MABContainerHealthDetailsArgs(
        code = code,
        message = message,
        recommendations = recommendations,
        title = title,
    )
}
